# -*- coding: utf-8 -*-

""" Module summary description.

More detailed description.
"""
from functools import partial


def _mask(arrays, no_data):
    src = arrays[0]
    mask = arrays[1]
    src[mask == 1] = no_data

    return src


def _raster_mask(raster, geodataframe, driver, output_type, no_data, all_touched,
                 window_size):
    """ Apply mask into raster

    """
    mask = raster.__class__.rasterize(geodataframe,
                                      raster.crs.to_wkt(),
                                      raster.x_size,
                                      raster.y_size,
                                      raster.geo_transform,
                                      burn_values=[1],
                                      all_touched=all_touched)

    return raster.__class__.raster_calculation([raster, mask],
                                               partial(_mask, no_data=no_data),
                                               gdal_driver=driver,
                                               output_type=output_type,
                                               no_data=no_data,
                                               description="Compute mask",
                                               window_size=window_size,
                                               nb_processes=1,
                                               chunksize=1)



# -*- coding: utf-8 -*-

""" Module summary description.

More detailed description.
"""

__version__ = '1.3.14'
__author__ = 'Benjamin Pillot'
__email__ = 'benjaminpillot@riseup.net'


import gdal

GDAL_DEFAULT_DRIVER = gdal.GetDriverByName("Gtiff")



# -*- coding: utf-8 -*-

""" Module summary description.

More detailed description.
"""
from pyrasta.tools import _return_raster

try:
    from osgeo import gdal
except ImportError:
    import gdal


@_return_raster
def _merge(raster_class, out_file, gdal_driver,
           sources, bounds, data_type, no_data):
    """ Merge multiple raster sources

    """

    # Extent of all inputs
    if bounds is not None:
        dst_w, dst_s, dst_e, dst_n = bounds
    else:
        # scan input files
        xs = [item for src in sources for item in src.bounds[0:2]]
        ys = [item for src in sources for item in src.bounds[2::]]
        dst_w, dst_s, dst_e, dst_n = min(xs), min(ys), max(xs), max(ys)

    gdal.Warp(out_file, [src._gdal_dataset for src in sources],
              outputBounds=(dst_w, dst_s, dst_e, dst_n),
              format=gdal_driver.GetDescription(),
              srcNodata=[src.no_data for src in sources],
              dstNodata=no_data, outputType=data_type)
